@@ -1,4 +1,5 @@
 """Client."""
+
 from __future__ import annotations
 
 import asyncio
@@ -6,7 +7,6 @@ from collections import defaultdict
 from collections.abc import Callable
 from copy import deepcopy
 from datetime import datetime
-import functools
 import logging
 from operator import itemgetter
 import pprint
@@ -40,11 +40,6 @@ from .model.driver import Driver
 from .model.log_message import LogMessage
 from .model.version import VersionInfo, VersionInfoDataType
 
-try:
-    import orjson as json
-except ImportError:
-    import json
-
 SIZE_PARSE_JSON_EXECUTOR = 8192
 
 # Message IDs
@@ -424,14 +419,9 @@ class Client:
 
         await self.async_start_listening_logs()
 
-    async def disable_server_logging(self) -> None:
+    def disable_server_logging(self) -> None:
         """Disable logging from the server."""
-        if not self.connected or not self.driver:
-            raise InvalidState(
-                "Can't disable server logging when not connected to server"
-            )
         if not self._server_logging_enabled or not self._server_logger_unsubs:
-            LOGGER.info("Server logging is already disabled")
             return
 
         for unsub in self._server_logger_unsubs:
@@ -464,11 +454,9 @@ class Client:
 
         try:
             if len(msg.data) > SIZE_PARSE_JSON_EXECUTOR:
-                data: dict = await self._loop.run_in_executor(
-                    None, functools.partial(msg.json, loads=json.loads)
-                )
+                data: dict = await self._loop.run_in_executor(None, msg.json)
             else:
-                data = msg.json(loads=json.loads)
+                data = msg.json()
         except ValueError as err:
             raise InvalidMessage("Received invalid JSON.") from err
 
@@ -565,7 +553,7 @@ class Client:
                 }
             )
 
-        await self._client.send_json(message, dumps=json.dumps)
+        await self._client.send_json(message)
 
     async def __aenter__(self) -> Client:
         """Connect to the websocket."""
