@@ -1,4 +1,5 @@
 """Common models for statistics."""
+
 from __future__ import annotations
 
 from dataclasses import dataclass, field
@@ -51,7 +52,7 @@ class RouteStatistics:
         """Return repeaters."""
         assert self.client.driver
         return [
-            self.client.driver.controller.nodes[node_id]
+            self.client.driver.controller.nodes[int(node_id)]
             for node_id in self.data["repeaters"]
         ]
 
@@ -82,8 +83,8 @@ class RouteStatistics:
         assert self.client.driver
         assert len(node_ids) == 2
         return (
-            self.client.driver.controller.nodes[node_ids[0]],
-            self.client.driver.controller.nodes[node_ids[1]],
+            self.client.driver.controller.nodes[int(node_ids[0])],
+            self.client.driver.controller.nodes[int(node_ids[1])],
         )
 
     def as_dict(self) -> RouteStatisticsDict:
@@ -94,9 +95,11 @@ class RouteStatistics:
             "rssi": self.data.get("rssi"),
             "repeater_rssi": self.data.get("repeaterRSSI", []),
             "route_failed_between": (
-                self.route_failed_between[0],
-                self.route_failed_between[1],
-            )
-            if self.route_failed_between
-            else None,
+                (
+                    self.route_failed_between[0],
+                    self.route_failed_between[1],
+                )
+                if self.route_failed_between
+                else None
+            ),
         }
